package envoy.event;

/**
 * Signifies to the client that the handshake failed for the attached
 * reason.<br>
 * <br>
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>HandshakeRejection.java</strong><br>
 * Created: <strong>28 Jan 2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Common v0.3-alpha
 */
public class HandshakeRejection extends Event<String> {

	/**
	 * Select this value if a given password hash or user was incorrect.
	 */
	public static final String WRONG_PASSWORD_OR_USER = "Incorrect user name or password.";

	/**
	 * Select this value if the handshake could not be completed for some reason.
	 */
	public static final String INTERNAL_ERROR = "An internal error occured.";

	private static final long serialVersionUID = 0L;

	/**
	 * Creates an instance of {@link HandshakeRejection} with an empty reason.
	 *
	 * @since Envoy Common v0.3-alpha
	 */
	public HandshakeRejection() { super(""); }

	/**
	 * Creates an instance of {@link HandshakeRejection}.
	 *
	 * @param reason the reason why the handshake was rejected
	 * @since Envoy Common v0.3-alpha
	 */
	public HandshakeRejection(String reason) { super(reason); }
}
